==> lore-hook-dialogs-bootstrap-0.8.1.tgz: package/lib/fields/BooleanField.js <==
'use strict';

var React = require('react');

module.exports = React.createClass({
  displayName: 'BooleanField',

  propTypes: {
    label: React.PropTypes.string.isRequired,
    value: React.PropTypes.bool.isRequired,
    onChange: React.PropTypes.func.isRequired
  },

  getStyles: function getStyles() {
    return {
      checkbox: {
        width: 'inherit',
        height: 'inherit'
      }
    };
  },

  getDefaultProps: function getDefaultProps() {
    return {
      value: false
    };
  },

  onChange: function onChange(e) {
    var value = e.target.checked;

    this.props.onChange({
      target: {
        label: this.props.label,
        value: value
      }
    });
  },

  render: function render() {
    return React.createElement(
      'div',
      { className: 'checkbox' },
      React.createElement(
        'label',
        { className: 'control-label' },
        React.createElement('input', { type: 'checkbox', checked: this.props.value, onChange: this.onChange }),
        ' ',
        this.props.label
      )
    );
  }

  // render: function () {
  //   var styles = this.getStyles();
  //
  //   return (
  //     <div className="form-group">
  //       <label className="control-label">
  //         {this.props.label}
  //       </label>
  //       <input
  //         type="checkbox"
  //         className="form-control"
  //         style={styles.checkbox}
  //         checked={this.props.value}
  //         onChange={this.onChange} />
  //     </div>
  //   );
  // }
});

==> lore-hook-dialogs-bootstrap-0.9.0.tgz: package/lib/fields/BooleanField.js <==
'use strict';

var React = require('react');

module.exports = React.createClass({
  displayName: 'BooleanField',

  propTypes: {
    attribute: React.PropTypes.object.isRequired,
    label: React.PropTypes.string.isRequired,
    value: React.PropTypes.bool.isRequired,
    onChange: React.PropTypes.func.isRequired
  },

  getDefaultProps: function getDefaultProps() {
    return {
      value: false
    };
  },

  getStyles: function getStyles() {
    return {
      description: {
        marginTop: '-5px',
        marginBottom: '3px',
        color: '#777'
      }
    };
  },

  onChange: function onChange(e) {
    var value = e.target.checked;

    this.props.onChange({
      target: {
        label: this.props.label,
        value: value
      }
    });
  },

  render: function render() {
    var attribute = this.props.attribute;
    var styles = this.getStyles();

    return React.createElement(
      'div',
      { className: 'form-group' },
      React.createElement(
        'label',
        { className: 'control-label' },
        attribute.displayName || this.props.label
      ),
      React.createElement(
        'p',
        { style: styles.description },
        attribute.description
      ),
      React.createElement('input', { type: 'checkbox', checked: this.props.value, onChange: this.onChange })
    );
  }

  // render: function () {
  //   var styles = this.getStyles();
  //
  //   return (
  //     <div className="form-group">
  //       <label className="control-label">
  //         {this.props.label}
  //       </label>
  //       <input
  //         type="checkbox"
  //         className="form-control"
  //         style={styles.checkbox}
  //         checked={this.props.value}
  //         onChange={this.onChange} />
  //     </div>
  //   );
  // }
});
